@@ -54,6 +54,8 @@ public:
              };
 
    EcfFile();
+
+   /// This preserves the caches, used to avoid opening/stat of include file more than once.
 	EcfFile& operator=(const EcfFile& rhs);
 
 	/// use default copy constructor, assignment, destructor
@@ -92,7 +94,13 @@ public:
 	/// Pre-processing involves include expansion and variable substitution
 	/// Will throw std::runtime_error if pre processing fails
 	void pre_process(std::string& pre_processed_file);
-	void pre_process(std::vector<std::string> & user_edit_file, std::string& pre_processed_file);
+
+   /// Does full pre-processing:
+   ///   - include pre-processing
+   ///   - variable substitution
+   ///   - remove comment and manual sections
+   ///   - ignore %noop
+	void pre_process_user_file(std::vector<std::string> & user_edit_file, std::string& pre_processed_file);
 
 	/// Searches for the first %comment, then extracts all variables of the form
 	///   <name>  =  <value>
@@ -130,14 +138,16 @@ private:
  	void get_used_variables(std::string& used_variables) const;
  	bool get_used_variables(NameValueMap& used_variables, std::string& errorMsg) const;
  	void doCreateUsrFile() const;
+ 	bool file_exists(const std::string& file_path) const;
 
 	Node* node_;                         // Task or Alias or Container when pre-processing the man files
 	std::string  ecfMicroCache_;         // cache value of ECF_MICRO
 	std::string  script_path_or_cmd_;    // path to .ecf, .usr file or command
-	mutable std::string  job_size_;      // to be placed in log file during job submission
-	EcfFile::ScriptType    script_type_; // get script from a file, or from running a command
 	std::vector<std::string> jobLines_;  // Lines that will form the job file.
-	mutable std::vector< boost::shared_ptr<IncludeFileCache> > include_file_cache_; // only open include file once
+    mutable std::vector<boost::shared_ptr<IncludeFileCache> > include_file_cache_; // only open include file once
+    mutable std::vector<std::pair<std::string,bool> > file_stat_cache_; // Minimise calls to stat/kernel calls
+	mutable std::string  job_size_;      // to be placed in log file during job submission
+	EcfFile::ScriptType  script_type_;   // get script from a file, or from running a command
 };
 
 
@@ -157,7 +167,7 @@ private:
    //       only include directives in %nopp/%end are ignored
    void preProcess_line(const std::string& script_line );
    void preProcess_includes(const std::string& script_line);
-   std::string getIncludedFilePath( const std::string& include, const std::string& line, std::string& errormsg);
+   std::string getIncludedFilePath( const std::string& include, const std::string& line);
 
 private:
    EcfFile* ecfile_;
@@ -172,12 +182,12 @@ private:
    std::string pp_end_;
    std::string ecf_micro_;                 // constant until ecfmicro changes, then reset
 
-   std::string error_msg_;
    std::vector<std::string>& jobLines_;
    std::vector<std::string> tokens_;       // re-use to save memory
 
    std::vector<std::pair<std::string,int> > globalIncludedFileSet_;// test for recursive includes, <no _of times it was included>
    std::vector<std::string> include_once_set_;
+   std::string error_msg_;
 };
 
 #endif
