@@ -65,11 +65,7 @@ public:
    virtual void acceptVisitTraversor(ecf::NodeTreeVisitor& v);
    virtual void reset();
    virtual void begin();
-   virtual void requeue(
-            bool resetRepeats,
-            int clear_suspended_in_child_nodes,
-            bool reset_next_time_slot,
-            bool reset_relative_duration);
+   virtual void requeue(Requeue_args& args);
    bool begun() const { return begun_; }
    void reset_begin();
    virtual void update_generated_variables() const;
