@@ -324,11 +324,7 @@ void Task::begin()
 #endif
 }
 
-void Task::requeue(
-         bool resetRepeats,
-         int clear_suspended_in_child_nodes,
-         bool reset_next_time_slot,
-         bool reset_relative_duration)
+void Task::requeue(Requeue_args& args)
 {
    if (aliases_.empty()) {
       if (alias_no_ != 0) {
@@ -336,10 +332,7 @@ void Task::requeue(
       }
    }
 
-	Submittable::requeue(resetRepeats,
-	                     clear_suspended_in_child_nodes,
-	                     reset_next_time_slot,
-	                     reset_relative_duration);
+	Submittable::requeue(args);
 
 #ifdef DEBUG_STATE_CHANGE_NO
 	std::cout << "Task::requeue\n";
@@ -480,6 +473,18 @@ bool Task::resolveDependencies(JobsParam& jobsParam)
          return false;
       }
 
+      // Job cmd failed. Do not resubmit jobs, until *begin* or *re-queue*. ECFLOW-1216
+      if (get_flag().is_set(ecf::Flag::EDIT_FAILED)) {
+         return false; // pre-processing, variable subs, create directory, change job file permission failed
+      }
+      if (get_flag().is_set(ecf::Flag::NO_SCRIPT)) {
+         return false; // .ecf file location failed
+      }
+      if (get_flag().is_set(ecf::Flag::JOBCMD_FAILED)) {
+         return false; // variable substituion on JOB cmd failed
+      }
+
+
       // If the task was aborted, and we have not exceeded ECF_TRIES, then resubmit
       // otherwise ONLY in state QUEUED can we submit jobs
       std::string varValue;
