@@ -116,8 +116,6 @@ public:
    std::vector<ecf::CronAttr>::const_iterator cron_begin() const { return crons_.begin();}
    std::vector<ecf::CronAttr>::const_iterator cron_end() const { return crons_.end();}
 
-   void clear(); /// Clear *ALL* internal attributes
-
    /// Under the hybrid calendar some time dependent attributes may not be applicable
    /// i.e if day,date,cron attributes does correspond to 24 hours of today, then we
    /// need make them as complete.
@@ -128,6 +126,8 @@ public:
    void get_time_resolution_for_simulation(boost::posix_time::time_duration& resol) const;
    void get_max_simulation_duration(boost::posix_time::time_duration& duration) const;
 
+   bool empty() const { return (timeVec_.empty() && todayVec_.empty() && dates_.empty() && days_.empty() && crons_.empty()) ? true : false ;}
+
 private:
    Node*        node_; // *NOT* persisted must be set by the parent class
 
