@@ -223,7 +223,7 @@ BOOST_AUTO_TEST_CASE( test_server_stress_test_2 )
 #elif defined(_AIX)
    int load = 65; // On non linux systems use different load otherwise it takes to long
 #else
-   int load = 136;
+   int load = 130;
 #endif
 
 #ifdef ECF_OPENSSL
@@ -234,8 +234,18 @@ BOOST_AUTO_TEST_CASE( test_server_stress_test_2 )
    DurationTimer duration_timer;
    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
    theClient.set_throw_on_error(false);
+
+   // enable_auto_flush/disable_auto_flush was added in 4.9.0, hence disable for old server, which 
+   // automatically flush for log output anyway
+   // Remove getenv when default version is 4.9.0.
+   bool disable_test = false;
+   if (getenv("ECF_DISABLE_TEST_FOR_OLD_SERVERS")) disable_test = true;
+
    for(int i = 0; i < load; i++) {
 
+      if (!disable_test) {
+         BOOST_REQUIRE_MESSAGE( theClient.disable_auto_flush() == 0,"disable_auto_flush should return 0\n" << theClient.errorMsg());
+      }
       BOOST_REQUIRE_MESSAGE( theClient.pingServer() == 0, " ping should return 0\n" << theClient.errorMsg());
       BOOST_REQUIRE_MESSAGE( theClient.delete_all() == 0,CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n" << theClient.errorMsg());
       BOOST_REQUIRE_MESSAGE( theClient.loadDefs(path) == 0,"load defs failed \n" << theClient.errorMsg());
@@ -254,6 +264,9 @@ BOOST_AUTO_TEST_CASE( test_server_stress_test_2 )
       BOOST_REQUIRE_MESSAGE( theClient.get_log_path() == 0,"get_log_path should return 0\n" << theClient.errorMsg());
       BOOST_REQUIRE_MESSAGE( theClient.getLog(1) == 0,"get_log last line should return 0\n" << theClient.errorMsg());
       BOOST_REQUIRE_MESSAGE( theClient.flushLog() == 0,"flushLog should return 0\n" << theClient.errorMsg());
+      if (!disable_test) {
+         BOOST_REQUIRE_MESSAGE( theClient.query_auto_flush() == 0,"query_auto_flush should return 0\n" << theClient.errorMsg());
+      }
 
       BOOST_REQUIRE_MESSAGE( theClient.force("/suite1","unknown",true) == 0,"check should return 0\n" << theClient.errorMsg());
       BOOST_REQUIRE_MESSAGE( theClient.force("/suite1","complete",true) == 0,"check should return 0\n" << theClient.errorMsg());
@@ -324,8 +337,15 @@ BOOST_AUTO_TEST_CASE( test_server_stress_test_2 )
       BOOST_REQUIRE_MESSAGE( theClient.getDefs() == 0,CtsApi::get() << " failed should return 0\n" << theClient.errorMsg()); //60
       BOOST_REQUIRE_MESSAGE( theClient.defs().get(),"Server returned a NULL defs");
       BOOST_REQUIRE_MESSAGE( theClient.defs()->suiteVec().size() >= 1,"  no suite ?");
+      if (!disable_test) {
+         BOOST_REQUIRE_MESSAGE( theClient.enable_auto_flush() == 0,"enable_auto_flush should return 0\n" << theClient.errorMsg());
+      }
    }
-   cout << " Server handled " << load * 74
+
+   int no_of_client_calls = 74;
+   if (!disable_test) no_of_client_calls = 77;
+  
+   cout << " Server handled " << load * no_of_client_calls
         << " requests in boost_timer(" << boost_timer.elapsed()
         << ") DurationTimer(" << to_simple_string(duration_timer.elapsed())
         << ")" << endl;
