@@ -131,9 +131,13 @@ fi
 case $host in
 $localh )
   grep "^$localh" $servers || echo "$localh $localh $ECF_PORT" >> $servers
+
+  servers_ui=$HOME/.ecflow_ui/servers.txt
+  if [ -f $server_ui ] ; then 
+    grep "^$localh" $servers_ui || echo "$localh,$localh,$ECF_PORT,0,0" >> $servers_ui
+  fi
 ;;
 esac
- 
 date -u
 
 # ======================================================================================
@@ -190,7 +194,16 @@ set +e
 
 cp $ECF_CHECK    log/ 2>/dev/null
 cp $ECF_CHECKOLD log/ 2>/dev/null
-cp $ECF_LOG      log/ 2>/dev/null
+if [[ -f $ECF_LOG ]]; then 
+    STAMP=$(date +%Y%m%d.%H%M)
+    SIZE=$(du -Hm $ECF_LOG | awk '{print $1}') || SIZE=0
+    if [[ $SIZE -gt 100 ]]; then
+	     echo "Moving, compressing logfile ${SIZE}mb ${ECF_LOG}.${STAMP}.log"
+	     mv $ECF_LOG log/${ECF_LOG}.${STAMP}.log 2>/dev/null
+	     gzip -f log/${ECF_LOG}.${STAMP}.log 2>/dev/null
+    fi
+fi
+cp $ECF_LOG log/ 2>/dev/null  # allow logfile append in case of multiple restart
 
 if [ -f $ECF_HOST.$ECF_PORT.ecf.out ]; then
    cp $ECF_HOST.$ECF_PORT.ecf.out log/ 2>/dev/null
